@@ -590,7 +590,8 @@ class BaseExperiment:
 
     def fit_sklearn(
         self,
-        sample_weight : Optional["np.ndarray"] = None
+        sample_weight : Optional["np.ndarray"] = None,
+        **config
     )->"BaseEstimator":
         # for consistency with the logging style of pytorch_lightning.
         self.update_log_path()
@@ -600,6 +601,8 @@ class BaseExperiment:
         log_dir = f"{folder_dir}/version_{version}"
         self._create_folder(log_dir)
         self.logger = SummaryWriter(log_dir=log_dir)
+        if sample_weight is None:
+            sample_weight = np.ones_like(self.y_train)
         self.model.fit(self.X_train, self.y_train, sample_weight)
         y_train_preds = self.model.predict(self.X_train)
         train_acc = (self.y_train==y_train_preds).astype(float).mean()
