@@ -43,12 +43,12 @@ class BCELossMetrics():
         y_hat : "torch.Tensor", 
         labels : "torch.Tensor"
     ):
-        
+        y_hat = y_hat.type_as(labels)
         loss = self.loss_function(y_hat, labels.reshape(-1)).squeeze()
         accuracy = self.accuracy(y_hat, labels)
         auc = self.auc(y_hat, labels.int())
         return loss, accuracy, auc
-        
+
 class CELossMetrics():
     def __init__(self, n_classes):
         self.loss_function = nn.CrossEntropyLoss()
@@ -72,10 +72,10 @@ class CELossMetrics():
         y_hat, 
         labels : "torch.Tensor"
     ):
-        
-        loss = self.loss_function(y_hat, labels.reshape(-1).long()).squeeze()
-        accuracy = self.accuracy(y_hat, labels)
-        auc = self.auc(y_hat, labels)
+        y_hat = y_hat.type_as(y_hat)
+        loss = self.loss_function(y_hat.type_as(labels.float()), labels.reshape(-1).long()).squeeze()
+        accuracy = self.accuracy(y_hat.type_as(labels.float()), labels)
+        auc = self.auc(y_hat.type_as(labels.float()), labels)
         return loss, accuracy, auc
 
 class SegCELossMetrics():
@@ -287,18 +287,6 @@ def plot_img_and_mask(img, mask):
     plt.show()
 
 
-# for binary_tree.py
-def unique_counts(labels):
-    results = {}
-    for label in labels:
-        value = label.item()
-        if value not in results.keys():
-            results.update({value : 0})
-        
-        results[value] += 1
-    
-    return results
-
 def log2(x):
     return log(x) / log(2)
     
@@ -311,27 +299,6 @@ def entropy(labels):
         ent = ent - p * log2(p)
     return ent
 
-def split_function(vector, column, value):
-    """
-    Split function
-    """
-    return vector[column] >= value
-
-
-def divide_set(X, y, column, value):
-    """
-    Divide the sets into two different sets along a specific dimension and value.
-    """
-    set_1 = [(vector, label) for vector, label in zip(X, y) if split_function(vector, column, value)]
-    set_2 = [(vector, label) for vector, label in zip(X, y) if not split_function(vector, column, value)]
-
-    X_set_1 = [element[0] for element in set_1]
-    X_set_2 = [element[0] for element in set_2]
-    y_set_1 = [element[1] for element in set_1]
-    y_set_2 = [element[1] for element in set_2]
-
-    return X_set_1, y_set_1, X_set_2, y_set_2
-
 def rearrange_dims(dims, in_format, dataformats="NCHW"):
     def find_mapping(in_format, dataformats):
         mappings = list(permutations([0,1,2]))
@@ -360,3 +327,53 @@ def rearrange_dims(dims, in_format, dataformats="NCHW"):
     else:
         raise ValueError(f"Wrong dimension {dims} for an input.")
     return dims
+
+def conv_dim(
+    in_dim, out_channels,
+    padding, dilation, kernel_size, stride,
+    dataformat="NCHW"
+):
+
+    if isinstance(padding, int):
+        padding = (padding, padding)
+    if isinstance(dilation, int):
+        dilation = (dilation, dilation)
+    if isinstance(kernel_size, int):
+        kernel_size = (kernel_size, kernel_size)
+    if isinstance(stride, int):
+        stride = (stride, stride)
+    
+    c_in, h_in, w_in, c_out, h_out, w_out = None
+
+    mapping_in = {"C":c_in, "H":h_in, "W":w_in}
+    for idx, c in enumerate(dataformat):
+        if c != "N":
+            mapping_in[c] = in_dim[idx]
+    
+    h_num = h_in + 2 * padding[0] - dilation[0]*(kernel_size[0]-1)-1
+    h_den = stride[0]
+    h_out = int(h_num/h_den+1)
+
+    w_num = w_in + 2 * padding[1] - dilation[1]*(kernel_size[1]-1)-1
+    w_den = stride[1]
+    w_out = int(w_num/w_den+1)
+
+    c_out = out_channels
+    
+    out_dim = None 
+    if dataformat == "NCHW":
+        out_dim = (c_out, h_out, w_out)
+    elif dataformat == "NCWH":
+        out_dim = (c_out, w_out, h_out)
+    elif dataformat == "NHWC":
+        out_dim = (h_out, w_out, c_out)
+    elif dataformat == "NHCW":
+        out_dim = (h_out, c_out, w_out)
+    elif dataformat == "NWHC":
+        out_dim = (w_out, h_out, c_out)
+    elif dataformat == "NWCH":
+        out_dim = (w_out, c_out, h_out)
+    else:
+        raise ValueError(f"Wrong type of dataformat {dataformat}. It should start with 'N' and be followed by a permutation of 'HWC'.")
+    
+    return out_dim 
\ No newline at end of file
